import pathToRegexp from 'path-to-regexp';
import queryString from 'query-string';
import { queryOne } from '../../services/mproduct';

export default {
  namespace: 'mproductDetail',

  state: {
    filters: {},
    currentItem: {},
    itemLoading: false,
  },

  subscriptions: {
    setup({ dispatch, history }) {
      history.listen(({ pathname, state, search }) => {
        const match = pathToRegexp('/products/view').exec(pathname);
        if (match) {
          const params = queryString.parse(search);
          dispatch({ type: 'queryOne', payload: { ...params } });
          dispatch({ type: 'saveFilters', payload: state });
        }
      });
    },
  },

  effects: {
    // 查询一条渠道方产品详情 /merchant/product/detail?pid=xxx&merchantId=xxx
    * queryOne({ payload }, { call, put }) {
      yield put({ type: 'changeLoading', payload: { itemLoading: true } });
      const { data, success } = yield call(queryOne, payload);
      if (success) {
        yield put({ type: 'querySuccess', payload: { ...data } });
      }
      yield put({ type: 'changeLoading', payload: { itemLoading: false } });
    },
  },

  reducers: {
    changeLoading(state, { payload }) {
      return { ...state, ...payload };
    },
    querySuccess(state, { payload }) {
      return { ...state, currentItem: payload };
    },
    saveFilters(state, { payload: filters }) {
      return { ...state, filters };
    },
  },
};
